.. api.model:

*****
model
*****

This is the main model code.

This class is defined in ``pyDeltaRCM.model``. 


The DeltaModel class and all attributes and methods
---------------------------------------------------

.. currentmodule:: pyDeltaRCM.model

.. autosummary:: 
	:toctree: ../../_autosummary

	~DeltaModel




Model configuration reference
-----------------------------

.. toctree::
    :maxdepth: 1

    yaml_defaults
    model_hooks
